@@ -3,7 +3,7 @@
 
 #include <QtGui>
 
-#include "bookwindow.h"
+#include "adopterwindow.h"
 
 class QString;
 class QModelIndex;
@@ -12,8 +12,9 @@ class BookView;
 class Book;
 class FullScreenWindow;
 class Progress;
+class TranslucentButton;
 
-class MainWindow: public BookWindow
+class MainWindow: public AdopterWindow
 {
     Q_OBJECT
 
@@ -38,6 +39,8 @@ public slots:
     void showChapters();
     void onGoToChapter(int index);
     void about();
+    void goToNextPage();
+    void goToPreviousPage();
 
 protected:
     void closeEvent(QCloseEvent *event);
@@ -57,8 +60,6 @@ private:
     QAction *fullScreenAction;
     QAction *forwardAction;
     QAction *backwardAction;
-    QAction *previousAction;
-    QAction *nextAction;
     QAction *chaptersAction;
     QToolBar *toolBar;
     QDialog *settings;
@@ -67,6 +68,8 @@ private:
     FullScreenWindow *fullScreenWindow;
     int preventBlankingTimer;
     Progress *progress;
+    TranslucentButton *previousButton;
+    TranslucentButton *nextButton;
 };
 
 #endif // MAINWINDOW_H
