@@ -27,10 +27,6 @@ public:
     QModelIndex nowReading() const;
     Book *book(const QModelIndex &index);
     QStringList bookPaths();
-    QStringList folders() const;
-    bool addFolder(const QString &folder);
-    bool removeFolder(const QString &folder);
-    void scanFolders();
 
 signals:
     void nowReadingChanged();
@@ -49,7 +45,6 @@ private:
     static Library *mInstance;
     QList<Book *> mBooks;
     QModelIndex mNowReading;
-    QStringList mFolders;
 };
 
 #endif // LIBRARY_H
